pub(crate) struct MuxConnection {
send_queues: HashMap<ProtocolID, Arc<AsyncQueue<PeerNetMsg>>>,
recv_queues: HashMap<ProtocolID, Arc<AsyncQueue<ProtocolEvent>>>,
quic_conn: QuicConn,
}Expand description
QUIC path: one stream per protocol, each with its own writer task.
send_queues and recv_queues are keyed by protocol id.
Fields
send_queues: HashMap<ProtocolID, Arc<AsyncQueue<PeerNetMsg>>>recv_queues: HashMap<ProtocolID, Arc<AsyncQueue<ProtocolEvent>>>quic_conn: QuicConnImplementations
Sourceimpl MuxConnection
impl MuxConnection
Sourcepub(crate) async fn from_queued(
queued: QueuedConn,
negotiated: &HashSet<ProtocolID>,
proto_ids: impl IntoIterator<Item = ProtocolID>,
task_group: &TaskGroup,
) -> Result<Self>
pub(crate) async fn from_queued( queued: QueuedConn, negotiated: &HashSet<ProtocolID>, proto_ids: impl IntoIterator<Item = ProtocolID>, task_group: &TaskGroup, ) -> Result<Self>
Open / accept one QUIC stream per negotiated protocol and spawn a reader + writer task for each.